@@ -24,7 +24,7 @@ zoo <- function (x = NULL, order.by = index(x), frequency = NULL,
 
     if(!is.null(frequency)) {
       delta <- suppressWarnings(try(diff(as.numeric(order.by)), silent = TRUE))
-      freqOK <- if(class(delta) == "try-error" || any(is.na(delta))) FALSE
+      freqOK <- if(inherits(delta, "try-error") || anyNA(delta)) FALSE
         else if(length(delta) < 1) TRUE
         else identical(all.equal(delta*frequency, round(delta*frequency)), TRUE)
       if(!freqOK) {
@@ -202,6 +202,20 @@ str.zoo <- function(object, ...)
   return(rval)
 }
 
+.DollarNames.zoo <- function(x, pattern = "") {
+  dn <- dimnames(x)
+  if(is.null(dn)) {
+    character(0)
+  } else {
+    cn <- dn[[2]]
+    if(is.null(cn)) {
+      character(0)
+    } else {
+      grep(pattern, cn, value = TRUE)
+    }
+  }
+}
+
 "$.zoo" <- function(object, x) {
   if(length(dim(object)) != 2) stop("not possible for univariate zoo series")
   if(is.null(colnames(object))) stop("only possible for zoo series with column names")
